@@ -7,10 +7,7 @@
 #     modify it under the same terms as Perl itself.
 
 package SNMP;
-$VERSION = '5.0404';   # current release version number
-
-use strict;
-use warnings;
+$VERSION = '5.4';   # current release version number
 
 require Exporter;
 require DynaLoader;
@@ -49,12 +46,11 @@ use NetSNMP::default_store (':all');
 );
 
 sub AUTOLOAD {
-    no strict;
     # This AUTOLOAD is used to 'autoload' constants from the constant()
     # XS function.  If a constant is not found then control is passed
     # to the AUTOLOAD in AutoLoader.
     my($val,$pack,$file,$line);
-    my $constname;
+    local($constname);
     ($constname = $AUTOLOAD) =~ s/.*:://;
     # croak "&$module::constant not defined" if $constname eq 'constant';
     $val = constant($constname, @_ ? $_[0] : 0);
@@ -78,23 +74,16 @@ bootstrap SNMP;
 # Preloaded methods go here.
 
 # Package variables
-tie $SNMP::debugging,         'SNMP::DEBUGGING';
-tie $SNMP::debug_internals,   'SNMP::DEBUG_INTERNALS';
-tie $SNMP::dump_packet,       'SNMP::DUMP_PACKET';
-tie %SNMP::MIB,               'SNMP::MIB';
-tie $SNMP::save_descriptions, 'SNMP::MIB::SAVE_DESCR';
-tie $SNMP::replace_newer,     'SNMP::MIB::REPLACE_NEWER';
-tie $SNMP::mib_options,       'SNMP::MIB::MIB_OPTIONS';
+tie $SNMP::debugging, SNMP::DEBUGGING;
+tie $SNMP::debug_internals, SNMP::DEBUG_INTERNALS;
+tie $SNMP::dump_packet, SNMP::DUMP_PACKET;
+tie %SNMP::MIB, SNMP::MIB;
+tie $SNMP::save_descriptions, SNMP::MIB::SAVE_DESCR;
+tie $SNMP::replace_newer, SNMP::MIB::REPLACE_NEWER;
+tie $SNMP::mib_options, SNMP::MIB::MIB_OPTIONS;
 
 %SNMP::V3_SEC_LEVEL_MAP = (noAuthNoPriv => 1, authNoPriv => 2, authPriv =>3);
 
-use vars qw(
-  $auto_init_mib $use_long_names $use_sprint_value $use_enums
-  $use_numeric %MIB $verbose $debugging $dump_packet $save_descriptions
-  $best_guess $non_increasing $replace_newer %session_params
-  $debug_internals $mib_options
-);
-
 $auto_init_mib = 1; # enable automatic MIB loading at session creation time
 $use_long_names = 0; # non-zero to prefer longer mib textual identifiers rather
                    # than just leaf indentifiers (see translateObj)
@@ -497,7 +486,7 @@ sub new {
        $this->{Context} ||= 
 	   NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
 		         NetSNMP::default_store::NETSNMP_DS_LIB_CONTEXT()) || '';
-       $this->{AuthProto} ||= 'DEFAULT'; # defaults to the library's default
+       $this->{AuthProto} ||= 'DEFAULT'; # use the library's default
        $this->{AuthPass} ||=
        NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
 		     NetSNMP::default_store::NETSNMP_DS_LIB_AUTHPASSPHRASE()) ||
@@ -509,7 +498,7 @@ sub new {
        $this->{AuthLocalizedKey} ||= '';
        $this->{PrivLocalizedKey} ||= '';
 
-       $this->{PrivProto} ||= 'DEFAULT';  # defaults to hte library's default
+       $this->{PrivProto} ||= 'DEFAULT';  # use the library's default
        $this->{PrivPass} ||=
        NetSNMP::default_store::netsnmp_ds_get_string(NetSNMP::default_store::NETSNMP_DS_LIBRARY_ID(), 
 		     NetSNMP::default_store::NETSNMP_DS_LIB_PRIVPASSPHRASE()) ||
@@ -652,6 +641,8 @@ sub get {
 }
 
 
+use strict;
+
 my $have_netsnmp_oid = eval { require NetSNMP::OID; };
 sub gettable {
 
@@ -694,7 +685,7 @@ sub gettable {
 	    if ($parse_indexes) {
 		# get indexes
 		my @indexes =
-		  @{$SNMP::MIB{$textnode}{'children'}[0]{'indexes'} || [] };
+		  @{$SNMP::MIB{$textnode}{'children'}[0]{'indexes'}};
 		# quick translate into a hash
 		map { $indexes{$_} = 1; } @indexes;
 	    }
@@ -710,8 +701,7 @@ sub gettable {
 		# some tables are only indexes, and we need to walk at
 		# least one column.  We pick the last.
 		push @{$state->{'columns'}}, $root_oid . ".1." .
-		  $children->[$#$children]{'subID'}
-		  if ref($state) eq 'HASH' and ref($children) eq 'HASH';
+		  $children->[$#$children]{'subID'};
 	    }
 	}
     } else {
@@ -741,7 +731,7 @@ sub gettable {
     $vbl = $state->{'varbinds'};
 	
     my $repeatcount;
-    if ($this->{Version} eq '1' || $state->{'options'}{nogetbulk}) {
+    if ($this->{Version} == 1 || $state->{'options'}{nogetbulk}) {
 	$state->{'repeatcount'} = 1;
     } elsif ($state->{'options'}{'repeat'}) {
 	$state->{'repeatcount'} = $state->{'options'}{'repeat'};
@@ -763,7 +753,7 @@ sub gettable {
     # call the next processing function ourself.
     #
     if ($state->{'options'}{'callback'}) {
-	if ($this->{Version} ne '1' && !$state->{'options'}{'nogetbulk'}) {
+	if ($this->{Version} > 1 && !$state->{'options'}{'nogetbulk'}) {
 	    $res = $this->getbulk(0, $state->{'repeatcount'}, $vbl,
 				  [\&_gettable_do_it, $this, $vbl,
 				   $parse_indexes, $textnode, $state]);
@@ -773,7 +763,7 @@ sub gettable {
 				   $parse_indexes, $textnode, $state]);
 	}
     } else {
-	if ($this->{Version} ne '1' && !$state->{'options'}{'nogetbulk'}) {
+	if ($this->{Version} > 1 && !$state->{'options'}{'nogetbulk'}) {
 	    $res = $this->getbulk(0, $state->{'repeatcount'}, $vbl);
 	} else {
 	    $res = $this->getnext($vbl);
@@ -855,7 +845,7 @@ sub _gettable_do_it() {
         # call the next processing function ourself.
         #
 	if ($state->{'options'}{'callback'}) {
-	    if ($this->{Version} ne '1' && !$state->{'options'}{'nogetbulk'}) {
+	    if ($this->{Version} > 1 && !$state->{'options'}{'nogetbulk'}) {
 		$res = $this->getbulk(0, $state->{'repeatcount'}, $vbl,
 				      [\&_gettable_do_it, $this, $vbl,
 				       $parse_indexes, $textnode, $state]);
@@ -866,7 +856,7 @@ sub _gettable_do_it() {
 	    }
 	    return;
 	} else {
-	    if ($this->{Version} ne '1' && !$state->{'options'}{'nogetbulk'}) {
+	    if ($this->{Version} > 1 && !$state->{'options'}{'nogetbulk'}) {
 		$res = $this->getbulk(0, $state->{'repeatcount'}, $vbl);
 	    } else {
 		$res = $this->getnext($vbl);
@@ -921,6 +911,7 @@ sub _gettable_end_routine {
 	}
     }
 }
+no strict;
 
 
 sub fget {
@@ -943,8 +934,8 @@ sub fget {
 
    SNMP::_get($this, $this->{RetryNoSuch}, $varbind_list_ref, $cb);
 
-   foreach my $varbind (@$varbind_list_ref) {
-     my $sub = $this->{VarFormats}{$varbind->[$SNMP::Varbind::tag_f]} ||
+   foreach $varbind (@$varbind_list_ref) {
+     $sub = $this->{VarFormats}{$varbind->[$SNMP::Varbind::tag_f]} ||
 	 $this->{TypeFormats}{$varbind->[$SNMP::Varbind::type_f]};
      &$sub($varbind) if defined $sub;
      push(@res, $varbind->[$SNMP::Varbind::val_f]);
@@ -996,8 +987,8 @@ sub fgetnext {
 
    SNMP::_getnext($this, $varbind_list_ref, $cb);
 
-   foreach my $varbind (@$varbind_list_ref) {
-     my $sub = $this->{VarFormats}{$varbind->[$SNMP::Varbind::tag_f]} ||
+   foreach $varbind (@$varbind_list_ref) {
+     $sub = $this->{VarFormats}{$varbind->[$SNMP::Varbind::tag_f]} ||
 	 $this->{TypeFormats}{$varbind->[$SNMP::Varbind::type_f]};
      &$sub($varbind) if defined $sub;
      push(@res, $varbind->[$SNMP::Varbind::val_f]);
@@ -1076,7 +1067,7 @@ sub bulkwalk {
    return defined($cb) ? $res[0] : \@res;
 }
 
-my %trap_type = (coldStart => 0, warmStart => 1, linkDown => 2, linkUp => 3,
+%trap_type = (coldStart => 0, warmStart => 1, linkDown => 2, linkUp => 3,
 	      authFailure => 4, egpNeighborLoss => 5, specific => 6 );
 sub trap {
 # (v1) enterprise, agent, generic, specific, uptime, <vars>
@@ -1168,7 +1159,7 @@ sub inform {
 }
 
 package SNMP::TrapSession;
-@SNMP::TrapSession::ISA = ('SNMP::Session');
+@ISA = ('SNMP::Session');
 
 sub new {
    my $type = shift;
@@ -1183,11 +1174,11 @@ sub new {
 
 package SNMP::Varbind;
 
-my $tag_f = 0;
-my $iid_f = 1;
-my $val_f = 2;
-my $type_f = 3;
-my $time_f = 4;
+$tag_f = 0;
+$iid_f = 1;
+$val_f = 2;
+$type_f = 3;
+$time_f = 4;
 
 sub new {
    my $type = shift;
@@ -1309,7 +1300,7 @@ sub FETCH {
     my $key = shift;
 
     if (!defined $this->{$key}) {
-	tie(%{$this->{$key}}, 'SNMP::MIB::NODE', $key) or return undef;
+	tie(%{$this->{$key}}, SNMP::MIB::NODE, $key) or return undef;
     }
     $this->{$key};
 }
